@@ -52,23 +52,102 @@ class RustResponseBytes:
     FastAPI detects this type and sends bytes directly without any
     Python serialization or string operations.
 
+    This class supports optional schema_type tracking for debugging and
+    provides a to_json() method for testing purposes (not recommended for
+    production due to performance overhead).
+
     WORKAROUND: Fixes known Rust bug where closing brace is missing for
     data object when query has nested objects. This is a temporary fix
     until fraiseql-rs is updated.
+
+    Args:
+        data: Pre-serialized JSON bytes from Rust
+        schema_type: Optional GraphQL schema type name for debugging (e.g., "Product", "User")
+
+    Examples:
+        >>> # Basic usage (existing code - backwards compatible)
+        >>> response = RustResponseBytes(b'{"data":{"hello":"world"}}')
+        >>> bytes(response)
+        b'{"data":{"hello":"world"}}'
+
+        >>> # With schema type tracking (Phase 3 enhancement)
+        >>> response = RustResponseBytes(b'{"data":{"products":[]}}', schema_type="Product")
+        >>> response.schema_type
+        'Product'
+
+        >>> # Testing with to_json() (Phase 3 - for tests only!)
+        >>> response.to_json()
+        {'data': {'products': []}}
     """
 
-    __slots__ = ("_data", "_fixed", "content_type")
+    __slots__ = ("_data", "_fixed", "_schema_type", "content_type")
 
-    def __init__(self, data: bytes) -> None:
+    def __init__(self, data: bytes, schema_type: Optional[str] = None) -> None:
         self._data = data
         self.content_type = "application/json"
         self._fixed = False
+        self._schema_type = schema_type
 
     @property
     def bytes(self) -> bytes:
         """Backward compatibility property for accessing the data."""
         return self._data
 
+    @property
+    def schema_type(self) -> Optional[str]:
+        """Get the GraphQL schema type name for this response.
+
+        This property is useful for debugging and understanding what type
+        the RustResponseBytes represents. For example, if this response
+        contains a list of Product objects, schema_type would be "Product".
+
+        Returns:
+            The GraphQL schema type name, or None if not set
+
+        Examples:
+            >>> response = RustResponseBytes(b'{"data":{"products":[]}}', schema_type="Product")
+            >>> response.schema_type
+            'Product'
+
+            >>> response = RustResponseBytes(b'{"data":{}}')
+            >>> response.schema_type is None
+            True
+        """
+        return self._schema_type
+
+    def to_json(self) -> dict:
+        """Parse the response bytes as JSON and return as dict.
+
+        ⚠️ WARNING: This method is intended for TESTING ONLY!
+
+        In production, RustResponseBytes should be sent directly to the client
+        via __bytes__() without any parsing. This method defeats the purpose
+        of the zero-copy architecture and should only be used in test code
+        for assertions.
+
+        Returns:
+            Parsed JSON as a Python dict
+
+        Raises:
+            json.JSONDecodeError: If the bytes don't contain valid JSON
+
+        Examples:
+            >>> response = RustResponseBytes(b'{"data":{"hello":"world"}}')
+            >>> response.to_json()
+            {'data': {'hello': 'world'}}
+
+            >>> # In tests, you can use this to verify structure
+            >>> data = response.to_json()
+            >>> assert data["data"]["hello"] == "world"
+
+            >>> # But DON'T use this in production - use __bytes__() instead!
+            >>> bytes(response)  # ✅ Good - zero-copy
+            b'{"data":{"hello":"world"}}'
+        """
+        # Use __bytes__() to get the (potentially fixed) bytes
+        data_bytes = self.__bytes__()
+        return json.loads(data_bytes)
+
     def __bytes__(self) -> bytes:
         # Workaround for Rust bug: Check if JSON is missing closing brace
         if not self._fixed:
@@ -124,6 +203,7 @@ async def execute_via_rust_pipeline(
     type_name: Optional[str],
     is_list: bool = True,
     field_paths: Optional[list[list[str]]] = None,
+    field_selections: Optional[list[dict[str, Any]]] = None,
 ) -> RustResponseBytes:
     """Execute query and build HTTP response entirely in Rust.
 
@@ -141,9 +221,14 @@ async def execute_via_rust_pipeline(
         type_name: GraphQL type for transformation (e.g., "User")
         is_list: True for arrays, False for single objects
         field_paths: Optional field paths for projection (e.g., [["id"], ["firstName"]])
+        field_selections: Optional field selections with aliases and type info (NEW for Phase 3)
 
     Returns:
         RustResponseBytes ready for HTTP response
+
+    Note:
+        field_selections parameter is for Phase 3 aliasing support. Currently passed but not yet
+        used by Rust until Task 3.4 (Update FFI) is complete. Maintains backward compatibility.
     """
     async with conn.cursor() as cursor:
         await cursor.execute(query, params or {})
@@ -152,29 +237,24 @@ async def execute_via_rust_pipeline(
             rows = await cursor.fetchall()
 
             if not rows:
-                # Empty array response
                 response_bytes = fraiseql_rs.build_graphql_response(
                     json_strings=[],
                     field_name=field_name,
-                    type_name=None,  # No typename for empty
+                    type_name=None,
                     field_paths=None,
+                    is_list=True,
                 )
                 return RustResponseBytes(response_bytes)
 
             # Extract JSON strings (PostgreSQL returns as text)
             json_strings = [row[0] for row in rows if row[0] is not None]
 
-            # 🚀 UNIFIED API (v0.2.0):
-            # - Field projection: Filter only requested fields
-            # - Concatenate: ['{"id":"1"}', '{"id":"2"}'] → '[{"id":"1"},{"id":"2"}]'
-            # - Wrap: '[...]' → '{"data":{"users":[...]}}'
-            # - Transform: snake_case → camelCase + __typename
-            # - Encode: String → UTF-8 bytes
             response_bytes = fraiseql_rs.build_graphql_response(
                 json_strings=json_strings,
                 field_name=field_name,
                 type_name=type_name,
-                field_paths=field_paths,  # None = no projection
+                field_paths=field_paths,
+                is_list=True,
             )
 
             return RustResponseBytes(response_bytes)
@@ -182,24 +262,23 @@ async def execute_via_rust_pipeline(
         row = await cursor.fetchone()
 
         if not row or row[0] is None:
-            # Null response - use empty structure or null
             response_bytes = fraiseql_rs.build_graphql_response(
-                json_strings=[], field_name=field_name, type_name=None, field_paths=None
+                json_strings=[],
+                field_name=field_name,
+                type_name=None,
+                field_paths=None,
+                is_list=False,
             )
             return RustResponseBytes(response_bytes)
 
         json_string = row[0]
 
-        # 🚀 UNIFIED API (v0.2.0):
-        # - Field projection: Filter only requested fields
-        # - Wrap: '{"id":"1"}' → '{"data":{"user":{"id":"1"}}}'
-        # - Transform: snake_case → camelCase + __typename
-        # - Encode: String → UTF-8 bytes
         response_bytes = fraiseql_rs.build_graphql_response(
-            json_strings=[json_string],  # Single item as list
+            json_strings=[json_string],
             field_name=field_name,
             type_name=type_name,
-            field_paths=field_paths,  # None = no projection
+            field_paths=field_paths,
+            is_list=False,
         )
 
         return RustResponseBytes(response_bytes)
