@@ -6,6 +6,7 @@ optimized PostgreSQL queries using `jsonb_build_object` for minimal post-process
 """
 
 from collections.abc import Sequence
+from typing import Any
 
 from psycopg import sql
 from psycopg.sql import SQL, Composed, Identifier
@@ -87,7 +88,7 @@ def _determine_jsonb_operator(alias: str, field_name: str, typename: str | None
         if field_type is str:
             return "->>"  # Extract strings as text
         if hasattr(field_type, "__origin__"):
-            # Handle generic types like List[str], Optional[int], etc.
+            # Handle generic types like list[str], Optional[int], etc.
             origin = getattr(field_type, "__origin__", None)
             args = getattr(field_type, "__args__", ())
 
@@ -426,7 +427,7 @@ def _determine_jsonb_operator(alias: str, field_name: str, typename: str | None
     return "->>"
 
 
-def _convert_order_by_to_tuples(order_by):
+def _convert_order_by_to_tuples(order_by: Any) -> list[tuple[str, str]] | None:
     """Convert any OrderBy format to list of tuples.
 
     Args:
